/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Csaba Simon, Zsolt Simon
 * Contributor(s): 
 */

#ifndef _CONVERTER_HPP
#define _CONVERTER_HPP

#include <iconv.h>
#include <string>

const int CONVERTER_BUFFER_SIZE = 1024;

class ConverterException
{
public:
  /**
   * Constructor.
   * @param s The error message.
   */
  ConverterException(std::string s) : message(s) {};

  /**
   * Return the error message.
   * @return a string containing the error message
   */
  const std::string&  description() const { return message; }

private:
  std::string message;
};

class Converter
{
public:
  /**
   * Default constructor.
   */
  Converter();

  /**
   * Constructor.
   * @param code The character code from/to the conversion will be.
   */
  Converter(const std::string &code);

  /**
   * Destructor.
   */
  ~Converter();

  /**
   * Set the character code from/to the conversion will be.
   * @param code The character code from/to the conversion will be.
   * @return true if succesfull
   *         false for invalid character codes.
   */
  bool set_code(const std::string &code);

  /**
   * Convert from wstring to string.
   * @param w the wstring.
   * @return a string.
   */
  std::string from_wstring(const std::wstring &w);

  /**
   * Convert from string to wstring.
   * @param s the string.
   * @return a wstring.
   */
  std::wstring to_wstring(const std::string &s);

private:
  /**
   * Close the conversion descriptors
   */
  void close();

private:
  /**
   * the conversion descriptors
   */
  iconv_t cd_from, cd_to;
};

#endif /*_CONVERTER_HPP*/
