/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Zsolt Simon, Csaba Simon
 * Contributor(s): 
 */

#ifndef _HOSTTOKENIZER_HPP
#define _HOSTTOKENIZER_HPP

#include <string>
#include <vector>

//Carob includes
#include <ConnectionParameters.hpp>

typedef struct {
  std::string host;
  unsigned int port;
} HOSTPORT;

class HostTokenizerException
{
public:
  /**
   * Constructor.
   * @param s The error message.
   */
  HostTokenizerException(std::string s) : message(s) {};

  /**
   * Return the error message.
   * @return a string containing the error message
   */
  const std::string&  description() const { return message; }

private:
  std::string message;
};

class HostTokenizer
{
public:
  typedef std::vector<HOSTPORT>::const_iterator const_iterator;

	HostTokenizer(const char *str, const char *defaultpolicy = 0);
	~HostTokenizer() {}

  const_iterator begin() { return hosts.begin(); }
  const_iterator end() { return hosts.end(); }

  CarobNS::ConnectPolicy getPolicy() { return policy; }
private:
  std::vector<HOSTPORT> hosts;
  CarobNS::ConnectPolicy policy;
  
  bool validChar(const char *p, const char *first, int state);
  CarobNS::ConnectPolicy findPolicy(const char *pol, int len = 0);
};

#endif /*_HOSTTOKENIZER_HPP*/
