/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Zsolt Simon, Csaba Simon
 * Contributor(s): 
 */

#ifndef _INIPARSER_HPP
#define _INIPARSER_HPP

#include <string>
#include <map>

class IniParser
{
public:
  /**
   * Open the file and parse it.
   * @param name the name of the file
   */
  bool parseFile(const char *name);

	/**
	 * Get the value of the option name in the group
	 * @param group the group name
	 * @param name the option name
	 * @return the value of the option name as string
	 */
  std::string get(std::string group, std::string name) const;

protected:
  void removeLeadingSpaces(std::string& s);
  void removeTrailingSpaces(std::string& s);
  void removeComments(std::string& s);
  void removeSpacesAndComments(std::string& s);

  bool parseGroup(std::string line, std::string& group);
  void parseName(std::string line, std::string group);
  std::string parseValue(std::string value);

private:
	/**
	 * holds the name=value pairs in each group
	 */
  std::map<std::string, std::map<std::string, std::string> > keys;
};

#endif /* _INIPARSER_HPP */
